<?php
namespace Netzmacher\Majordomo;

use TYPO3\CMS\Frontend\Plugin\AbstractPlugin;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;
use TYPO3\CMS\Core\TimeTracker\TimeTracker;

/***************************************************************
*  Copyright notice
*
*  (c) 2007-2017 - Dirk Wildt <wildt.at.die-netzmacher.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * Plugin 'Majordomo' for the 'majordomo' extension - subscribing in and unsubscribing to majordomo lists
 *
 * @author    Dirk Wildt <wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_majordomo_pi1
 */
class tx_majordomo_pi1 extends AbstractPlugin
{

  //////////////////////////////////////////////////////////////////////
  //
  // Variables for the TYPO3 Extension Management and Development

  public $prefixId      = 'tx_majordomo_pi1';                // Same as class name
  public $scriptRelPath = 'pi1/class.tx_majordomo_pi1.php';  // Path to this script relative to the extension dir.
  public $extKey        = 'majordomo';                       // The extension key.
  public $pi_checkCHash = true;
  protected $arr_extConfTemplate = FALSE;
  /**
   * @var \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer
   */
  protected $local_cObj    = null;
  // [ARRAY] Array with the values from the localconf.php and ext_conf_template.txt respectively
  // Variables for the TYPO3 Extension Management and Development


  //////////////////////////////////////////////////////////////////////
  //
  // Related objects

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1_config
   */
  protected $objConfig = null;

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1_confirm
   */
  protected $objConfirm = null;

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1_content
   */
  protected $objContent = null;

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1_form
   */
  protected $objForm = null;

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1_zz
   */
  public $objZz = null;

  /**
   * @var array
   */
  public $row = array();
  // Related objects




  //////////////////////////////////////////////////////////////////////
  //
  // Variables set by tx_majordomo_pi1_config

  protected $pidList         = FALSE;
  public $arrConfig          = FALSE;
  // [Array] Array with the configuration data from the flexform and from TypoScript.
  public $plugin_contentType = FALSE;
  // [String] Content Type of the current plugin (form or confirm).
  // Variables set by tx_majordomo_pi1_config


  //////////////////////////////////////////////////////////////////////
  //
  // Variables set by all classes

  public $arrPluginStatus    = FALSE;
  // [Array] Array with logs for the Plugin status
  // Variables set by all classes


  //////////////////////////////////////////////////////////////////////
  //
  // DRS - Development Reporting System

  // Developer Contact
  /**
   * @var \TYPO3\CMS\Core\TimeTracker\TimeTracker
   */
  protected $TT                     = null;
  /**
   * @var int
   */
  protected $startTime              = 0;

  protected $str_developer_name     = 'Dirk Wildt';
  protected $str_developer_mail     = 'wildt[at]die-netzmacher.de';
  protected $str_developer_phone    = '+49 8507 9237053';
  protected $str_developer_company  = 'Die Netzmacher';
  protected $str_developer_web      = 'http://die-netzmacher.de';
  protected $str_developer_typo3ext = 'http://typo3.org/extensions/repository/view/majordomo';
  protected $str_developer_lang     = 'german, english';
  protected $developer_contact      = FALSE; // @see init_drs()
  // Developer Contact

  // Booleans
  public    $b_drs_all       = FALSE;
  public    $b_drs_error     = FALSE;
  public    $b_drs_warn      = FALSE;
  public    $b_drs_checkmode = FALSE;
  public    $b_drs_email     = FALSE;
  public    $b_drs_perform   = FALSE;
  public    $b_drs_plugin    = FALSE;
  // Booleans
  // DRS - Development Reporting System


  // div
  /**
   * @var int
   */
  protected $i_drs_max_sql_result_len = 0;
  // div












/**
 * The main method of the PlugIn.
 *
 * @param	string		$content: The PlugIn content
 * @param	array		$conf: The PlugIn configuration
 * @return	string		The content that is displayed on the website
 */
  function main($content,$conf)
  {

    //////////////////////////////////////////////////////////////////////
    //
    // Init the global $conf, language processing, cObj methods, ...

    $this->conf = $conf;
    // Init methods for processing local language array
    $this->pi_loadLL();
    // Make cObj instance
    $this->local_cObj = GeneralUtility::makeInstance(ContentObjectRenderer::class);
    // Get the values from the localconf.php and ext_conf_template.txt respectively
    $this->arr_extConfTemplate = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf'][$this->extKey]);
    // Init the global $conf, language processing, cObj methods, ...



    //////////////////////////////////////////////////////////////////////
    //
    // Init DRS - Development Reporting System

    // Timetracking
    $this->TT = GeneralUtility::makeInstance(TimeTracker::class);
    $this->TT->start();
    $this->startTime = $this->TT->getDifferenceToStarttime();
    // Timetracking

    // Init DRS
    $this->init_drs();
    if ($this->b_drs_perform)
    {
      GeneralUtility::devlog('[INFO/DRS] START', $this->extKey, 0);
    }
    // Init DRS
    // Init DRS - Development Reporting System


    //////////////////////////////////////////////////////////////////////
    //
    // Set the Check Mode

    $this->b_drs_checkmode = $this->arr_extConfTemplate['check_mode'];
    if ($this->b_drs_checkmode)
    {
      GeneralUtility::devlog('[WARN/DRS] '.$this->extKey.' is running in CHECK MODE!', $this->extKey, 2);
    }
    // DRS - Extension in Check Mode?


    //////////////////////////////////////////////////////////////////////
    //
    // Require and init helper classes

    $this->require_classes();
    // Require and init helper classes


    //////////////////////////////////////////////////////////////////////
    //
    // Main Process

    // Allocates values to the global $arrConfig
    $this->objConfig->main();
    // Get the HTML content
    $content = $this->objContent->main();
    // Main Process


    //////////////////////////////////////////////////////////////////////
    //
    // DRS - Performance

    if ($this->b_drs_perform) {
      $endTime = $this->TT->getDifferenceToStarttime();
        GeneralUtility::devLog(
            '[INFO/DRS] END: ' . $this->extKey . ' needs ' . ($endTime - $this->startTime) . ' ms',
            $this->extKey,
            0
        );
    }
    // DRS - Performance


    //////////////////////////////////////////////////////////////////////
    //
    // Return the result (HTML string) wrapped in the class div

    return $this->pi_wrapInBaseClass($content);
    // Return the result (HTML string) wrapped in the class div
  }













  /***********************************************
   *
   * DRS - Development Reporting System
   *
   **********************************************/




  /**
 * Set the booleans for Warnings, Errors and DRS - Development Reporting System
 *
 * @return	void
 */
  function init_drs()
  {

    //////////////////////////////////////////////////////////////////////
    //
    // Prepaire the developer contact prompt

    $this->developer_contact =
        'company: '.  $this->str_developer_company.'<br />'.
        'name: '.     $this->str_developer_name   .'<br />'.
        'mail: <a href="mailto:'.$this->str_developer_mail.'" title="Send a mail">'.$this->str_developer_mail.'</a><br />'.
        'web: <a href="'.$this->str_developer_web.'" title="Website" target="_blank">'.$this->str_developer_web.'</a><br />'.
        'phone: '.    $this->str_developer_phone  .'<br />'.
        'languages: '.$this->str_developer_lang.'<br /><br />'.
        'TYPO3 Repository:<br /><a href="'.$this->str_developer_typo3ext.'" title="'.$this->extKey.' online" target="_blank">'.
    $this->str_developer_typo3ext.'</a>';
    $i_len = intval($this->conf['drs.']['sql.']['result.']['max_len']);
    if ($i_len > 0)
    {
      $this->i_drs_max_sql_result_len = $i_len;
    }
    // Prepaire the developer contact prompt


    //////////////////////////////////////////////////////////////////////
    //
    // Set the DRS mode

    if ($this->arr_extConfTemplate['drs_mode'] == 'All')
    {
      $this->b_drs_all          = TRUE;
      $this->b_drs_error        = TRUE;
      $this->b_drs_warn         = TRUE;
      $this->b_drs_email        = TRUE;
      $this->b_drs_perform      = TRUE;
      $this->b_drs_plugin       = TRUE;
      GeneralUtility::devlog('[INFO/DRS] DRS - Development Reporting System:<br />'.$arrConf['drs_mode'], $this->extKey, 0);
    }
    if ($arrConf['drs_mode'] == 'Email')
    {
      $this->b_drs_error        = TRUE;
      $this->b_drs_warn         = TRUE;
      $this->b_drs_email        = TRUE;
      $this->b_drs_perform      = TRUE;
      GeneralUtility::devlog('[INFO/DRS] DRS - Development Reporting System:<br />'.$arrConf['drs_mode'], $this->extKey, 0);
    }
    if ($arrConf['drs_mode'] == 'Plugin Check')
    {
      $this->b_drs_error        = TRUE;
      $this->b_drs_warn         = TRUE;
      $this->b_drs_perform      = TRUE;
      $this->b_drs_plugin       = TRUE;
      GeneralUtility::devlog('[INFO/DRS] DRS - Development Reporting System:<br />'.$arrConf['drs_mode'], $this->extKey, 0);
    }
    // Set the DRS mode

  }
















  /***********************************************
   *
   * Classes
   *
   **********************************************/



  /**
 * Make Instance for every Helper Class
 *
 * @return	void
 */
  function require_classes()
  {
    //////////////////////////////////////////////////////////////////////
    //
    // Require and init helper classes

    // Class with methods for configuration from flexform and TypoScript
    require_once('class.tx_majordomo_pi1_config.php');
    $this->objConfig        = GeneralUtility::makeInstance(tx_majordomo_pi1_config::class);
    $this->objConfig->pObj  = $this;
    $this->objConfig->conf  = $this->conf;
    // Class with methods for configuration from flexform and TypoScript

    // Class with methods for the content type confirmation
    require_once('class.tx_majordomo_pi1_confirm.php');
    $this->objConfirm       = GeneralUtility::makeInstance(tx_majordomo_pi1_confirm::class);
    $this->objConfirm->pObj = $this;
    $this->objConfirm->conf = $this->conf;
    // Class with methods for the content type confirmation

    // Class with methods for the content output
    require_once('class.tx_majordomo_pi1_content.php');
    $this->objContent       = GeneralUtility::makeInstance(tx_majordomo_pi1_content::class);
    $this->objContent->pObj = $this;
    $this->objContent->conf = $this->conf;
    // Class with methods for the content output

    // Class with methods for the content type form
    require_once('class.tx_majordomo_pi1_form.php');
    $this->objForm          = GeneralUtility::makeInstance(tx_majordomo_pi1_form::class);
    $this->objForm->pObj    = $this;
    $this->objForm->conf    = $this->conf;
    // Class with methods for the content type form

    // Class with so called zz methods
    require_once('class.tx_majordomo_pi1_zz.php');
    $this->objZz            = GeneralUtility::makeInstance(tx_majordomo_pi1_zz::class);
    $this->objZz->pObj      = $this;
    $this->objZz->conf      = $this->conf;
    // Class with so called zz methods
    // Require and init helper classes
  }
}