<?php
namespace Netzmacher\Majordomo;

use TYPO3\CMS\Core\Utility\GeneralUtility;

/***************************************************************
*  Copyright notice
*
*  (c) 2009-2017 - Dirk Wildt <wildt.at.die-netzmacher.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * The class tx_majordomo_pi1_config bundles all methods for the flexform but any wizard.
 * See Wizards in the wizard class.
 *
 * @author    Dirk Wildt <wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_majordomo_pi1
 */
class tx_majordomo_pi1_config
{
  /////////////////////////////////////////////////
  //
  // Vars set by methods in the current class

  /**
   * @var \Netzmacher\Majordomo\tx_majordomo_pi1
   */
  public $pObj = null;

  protected $arrConfig = FALSE;
  // [Array] Array with the configuration data from the flexform and from TypoScript.
  protected $uid = FALSE;
  // [Integer] Uid of the configuration record
  //   It will be stored in the parent object too.

  // Vars set by methods in the current class
  /**
   * @var array
   */
  public $conf = [];











/**
 * Allocate values to the globals
 * - plugin_contentType
 * - arrConfig
 *
 * @return	mixed
 */
  function main()
  {

    $pObj = $this->pObj;
    $cObj = $this->pObj->cObj;

    //////////////////////////////////////////////////////////////////////
    //
    // Init methods for pi_flexform

    $this->pObj->pi_initPIflexForm();
    // Init methods for pi_flexform


    //////////////////////////////////////////////////////////////////////
    //
    // Configuration independent of content type

    $this->configDefault();
    // Configuration independent of content type


    //////////////////////////////////////////////////////////////////////
    //
    // RETURN in case of a missing configuration record

    if (!is_array($this->pObj->row))
    {
    	$content = '
    		<div style="color:red;font-weight:bold;padding:1em;border:2em solid red;">
    			<h1>
    				'.$this->pObj->pi_getLL('plugin_error_title', '', TRUE).'
    			</h1>
    			<p>
			    	'.$this->pObj->pi_getLL('plugin_error_prompt', '', TRUE).'
    			</p>
    		</div>';
    	return $content;
    }
    // RETURN in case of a missing configuration record


    //////////////////////////////////////////////////////////////////////
    //
    // Configuration Content Type

    $str_contentType = $pObj->pi_getFFvalue($cObj->data['pi_flexform'], 'content_type');
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/TYPOSCRIPT] Content Type: '.$str_contentType, $this->pObj->extKey, 0);
    }

    // Downwards Compatibilty (upto 1.0)
    switch($str_contentType)
    {
      case('form'):
      case('confirm'):
        // Do noting
        break;
      case(0):
        $str_contentType = 'form';
        if ($this->pObj->b_drs_warn)
        {
          GeneralUtility::devlog('[WARN/UPDATE] Content Type is '.$str_contentType, $this->pObj->extKey, 2);
          GeneralUtility::devlog('[OK/UPDATE] Content Type is moved to: \'confirm\'.', $this->pObj->extKey, -1);
          GeneralUtility::devlog('[HELP/UPDATE] Please reload your Plugin!', $this->pObj->extKey, 1);
        }
        $int_key = count($this->pObj->arrPluginStatus['WARN']);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = $this->pObj->pi_getLL('plugin_prompt_oldValues', '', TRUE);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('plugin_todo_saveEdit', '', TRUE);
        break;
      default:
        $str_contentType = 'confirm';
        if ($this->pObj->b_drs_warn)
        {
          GeneralUtility::devlog('[WARN/UPDATE] Content Type is '.$str_contentType, $this->pObj->extKey, 2);
          GeneralUtility::devlog('[OK/UPDATE] Content Type is moved to: \'confirm\'.', $this->pObj->extKey, -1);
          GeneralUtility::devlog('[HELP/UPDATE] Please reload your Plugin!', $this->pObj->extKey, 1);
        }
        $int_key = count($this->pObj->arrPluginStatus['WARN']);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = $this->pObj->pi_getLL('plugin_prompt_oldValues', '', TRUE);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('plugin_todo_saveEdit', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    $this->pObj->plugin_contentType = $str_contentType;
    // Configuration Content Type



    //////////////////////////////////////////////////////////////////////
    //
    // Configuration depending on case of content type

    switch($str_contentType)
    {
      case('confirm'):
        $arrConfig = $this->configConfirm();
        break;
      case('form'):
        $arrConfig = $this->configForm();
        break;
      default:
        if ($this->pObj->b_drs_error)
        {
          GeneralUtility::devlog('[ERROR/TYPOSCRIPT] Content Type is undefined. Value: '.$str_contentType, $this->pObj->extKey, 3);
        }
	    	$content = '
	    		<div style="color:red;font-weight:bold;padding:1em;border:2em solid red;">
	    			<h1>
	    				'.$this->pObj->pi_getLL('plugin_error_title', '', TRUE).'
	    			</h1>
	    			<p>
				    	'.$this->pObj->pi_getLL('plugin_error_prompt', '', TRUE).'
	    			</p>
	    		</div>';
	    	return $content;


    }
    // Configuration depending on case of content type

    $this->pObj->arrConfig = $arrConfig;
    // Configuration main process


  }









  /***********************************************
   *
   * Allocates Values to arrConfig
   *
   **********************************************/




/**
 * Configuration independing of the case of the content type.
 * Allocates values to the globals
 * - pidList
 * - row
 *
 * @return	void
 */
  function configDefault()
  {

    //////////////////////////////////////////////////////////////////////
    //
    // Get Record Uid

    $this->uid = $this->pObj->pi_getFFvalue($this->pObj->cObj->data['pi_flexform'], 'typoscript_record');
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/TYPOSCRIPT] Uid of the configuration record: '.$this->uid, $this->pObj->extKey, 0);
    }
    if ($this->uid < 1)
    {
      if ($this->pObj->b_drs_warn)
      {
        GeneralUtility::devlog('[ERROR/PLUGIN] There isn\'t any configuration record!', $this->pObj->extKey, 3);
        GeneralUtility::devlog('[HELP/PLUGIN] Please configure your Plugin!', $this->pObj->extKey, 1);
      }
      $int_key = count($this->pObj->arrPluginStatus['ERROR']);
      $this->pObj->arrPluginStatus['ERROR'][$int_key]['prompt'] = $this->pObj->pi_getLL('plugin_prompt_noConfUid', '', TRUE);
    }
    // Get Record Uid


    //////////////////////////////////////////////////////////////////////
    //
    // Get Record

    // Allocates the row to the global $row
    $this->get_confRecord();
    // Get Record

  }









/**
 * Configuration in case of content type is confirm
 *
 * @return	array		$conf: The configuration array
 */
  function configConfirm()
  {


    ///////////////////////////////////////////
    //
    // Wrap Header

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['confirm.']['title_wrap'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] confirm.title_wrap is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript confirm.title_wrap '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['confirm_wrap_header'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] The Confirm Title hasn\'t any wrap. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Confirm Wrap Title: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['wrap_header'] = $str_value;
    // Wrap Header


    ///////////////////////////////////////////
    //
    // Wrap Prompt

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['confirm.']['text_wrap'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] confirm.text_wrap is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript confirm.text_wrap '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['confirm_wrap_prompt'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] The Confirm Prompt hasn\'t any wrap. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Confirm Wrap Prompt: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['wrap_prompt'] = $str_value;
    // Wrap Prompt


    ///////////////////////////////////////////
    //
    // Wrap Wrong Mail

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['confirm.']['wrong_mail_wrap'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] confirm.wrong_mail_wrap is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript confirm.wrong_mail_wrap '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['confirm_wrap_wrongmail'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] A wrong mail hasn\'t any wrap. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Confirm Wrap Prompt: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['wrap_wrongmail'] = $str_value;
    // Wrap Wrong Mail


    ///////////////////////////////////////////
    //
    // Mail of Majordomo Server

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['majordomo.']['address'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] majordomo.address is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript majordomo.address '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['mdom_mail'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[ERROR/PLUGIN] Majordomo Server hasn\'t any email address.', $this->pObj->extKey, 3);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['ERROR']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['prompt'] = 'Email Majordomo Server '.$str_missing;
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Email of Majordomo Server: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['mdom_mail'] = $str_value;
    // Mail of Majordomo Server


    ///////////////////////////////////////////
    //
    // Majordomo List

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['majordomo.']['list'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] majordomo.list is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript majordomo.list '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['mdom_list'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[ERROR/PLUGIN] Majordomo List hasn\'t any value.', $this->pObj->extKey, 3);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['ERROR']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['prompt'] = 'Majordomo List '.$str_missing;
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Email of Majordomo Server: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['mdom_list'] = $str_value;
    // Majordomo List


    ///////////////////////////////////////////
    //
    // Majordomo List Owner

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['majordomo.']['owner'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] majordomo.owner is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript majordomo.owner '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['mdom_owner'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[ERROR/PLUGIN] Majordomo List Owner hasn\'t any value.', $this->pObj->extKey, 3);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['ERROR']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['prompt'] = 'Majordomo List Owner '.$str_missing;
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Owner of Majordomo List: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['mdom_owner'] = $str_value;
    // Majordomo List Owner


    ///////////////////////////////////////////
    //
    // Sender Name

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['mail.']['name'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] mail.name is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript mail.name '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['sender_name'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[WARN/PLUGIN] Sender Name hasn\'t any value.', $this->pObj->extKey, 2);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['WARN']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'Sender Name '.$str_missing;
        $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Sender Name: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['sender_name'] = $str_value;
    // Sender Name


    ///////////////////////////////////////////
    //
    // Sender Mail

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['mail.']['from'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] mail.from is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript mail.from '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['sender_from'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[ERROR/PLUGIN] Sender Email hasn\'t any value.', $this->pObj->extKey, 3);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['ERROR']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['prompt'] = 'Sender Email '.$str_missing;
        $this->pObj->arrPluginStatus['ERROR'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Sender Mail: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['sender_from'] = $str_value;
    // Sender Name


    ///////////////////////////////////////////
    //
    // Sender Signature

    // Downwards Compatibilty (upto 1.0)
    $str_value = FALSE;
    if (is_array($this->conf['mail.']['signature.']))
    {
	    $arr_value = $this->conf['mail.']['signature.'];
	    $str_value = implode("\r\n", $arr_value);
    }
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] mail.signature is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript mail.signature '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['sender_signature'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[WARN/PLUGIN] Sender Signature hasn\'t any value.', $this->pObj->extKey, 2);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['WARN']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'Sender Signature '.$str_missing;
        $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Sender Signature: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['sender_signature'] = $str_value;
    // Sender Signature



    ///////////////////////////////////////////
    //
    // Sender Charset

    // Downwards Compatibilty (upto 1.0)
    $int_value = FALSE;
    $str_value = $this->conf['mail.']['charset'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] mail.charset is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript mail.charset '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
      if (strtolower($str_value) == 'utf-8')
      {
        $int_value = 0;
      }
      else
      {
        $int_value = 1;
      }
    }
    // Downwards Compatibilty (upto 1.0)
    if ($int_value === FALSE)       // <- Downwards Compatibilty (upto 1.0)
    {                               // <- Downwards Compatibilty (upto 1.0)
      $int_value = $this->pObj->row['sender_charset'];
      if ($int_value === FALSE)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[WARN/PLUGIN] Sender Charset hasn\'t any value.', $this->pObj->extKey, 2);
          GeneralUtility::devlog('[HELP/PLUGIN] Please configure the Plugin.', $this->pObj->extKey, 1);
        }
        $int_key      = count($this->pObj->arrPluginStatus['WARN']);
        $str_missing  = $this->pObj->pi_getLL('plugin_prompt_isMissing', '', TRUE);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'Sender Charset '.$str_missing;
        $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_edit', '', TRUE);
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Sender Charset [0: utf-8, 1: iso]: '.$int_value, $this->pObj->extKey, 0);
    }
    $arrConfig['sender_charset'] = $int_value;
    // Sender Charset


    ///////////////////////////////////////////
    //
    // Return the array arrConfig

    return $arrConfig;
    // Return the array arrConfig
  }












/**
 * Configuration in case of content type is form. Allocates values to
 * - $arrConfig
 *
 * @return	array		$arrConfig: The configuration array for the content type form
 */
  function configForm()
  {


    ///////////////////////////////////////////
    //
    // Page Confirm Uid

    $int_pageConfirmUid = $this->conf['pid.']['confirm'];
    if ($int_pageConfirmUid != '')
    {
    if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] pid.confirm is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript pid.confirm '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    if ($int_pageConfirmUid === FALSE || $int_pageConfirmUid == '')
    {
      $int_pageConfirmUid  = $this->pObj->pi_getFFvalue($this->pObj->cObj->data['pi_flexform'], 'page_confirm_uid');
      if ($int_pageConfirmUid === FALSE || $int_pageConfirmUid == '')
      {
        if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[WARN/TYPOSCRIPT] The plugin hasn\'t any uid for the confirmation page!<br />
            Your plugin won\'t work proper!.', $this->pObj->extKey, 2);
          GeneralUtility::devlog('[HELP/TYPOSCRIPT] Please configure the plugin.', $this->pObj->extKey, 1);
          GeneralUtility::devlog('[INFO/TYPOSCRIPT] We take the pid of the current page: '.$GLOBALS['TSFE']->id, $this->pObj->extKey, 1);
        }
        $int_pageConfirmUid = $GLOBALS['TSFE']->id;
        $int_key = count($this->pObj->arrPluginStatus['WARN']);
        $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = $this->pObj->pi_getLL('plugin_prompt_noConfirmUid', '', TRUE);
      }
    }
    // Page Confirm Uid


    ///////////////////////////////////////////
    //
    // Form Action

    $arrConfig['form_action'] = $this->pObj->pi_getPageLink($int_pageConfirmUid);
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/TYPOSCRIPT] Uid of confirmation page: '.$int_pageConfirmUid.'<br />
        Result: &lt;form action="'.$arrConfig['form_action'].'" ... &gt;', $this->pObj->extKey, 0);
    }
    // Form Action


    ///////////////////////////////////////////
    //
    // Default Mail

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['mail.']['default'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.mail.default is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.mail.default '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['mdom_default_mail'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] There isn\'t any default email. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Default Email: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['default_mail'] = $str_value;
    // Default Mail


    ///////////////////////////////////////////
    //
    // Wrap Header

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['title_wrap'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.title_wrap is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.title_wrap '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['form_wrap_header'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] The Form Title hasn\'t any wrap. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Form Wrap Title: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['wrap_header'] = $str_value;
    // Wrap Header


    ///////////////////////////////////////////
    //
    // Class Buttons

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['class.']['buttons'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.class.buttons is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.class.buttons '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['form_class_buttons'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] Class buttons hasn\'t any value. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Class buttons: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['class_buttons'] = $str_value;
    // Class Buttons


    ///////////////////////////////////////////
    //
    // Class Buttonleft

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['class.']['buttons.']['left'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.class.buttons.left is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.class.buttons.left '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['form_class_buttonleft'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] Class button left hasn\'t any value. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Class button left: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['class_buttonleft'] = $str_value;
    // Class Buttonleft


    ///////////////////////////////////////////
    //
    // Class Buttonright

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['class.']['buttons.']['right'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.class.buttons.right is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.class.buttons.right '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['form_class_buttonright'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] Class button right hasn\'t any value. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Class button right: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['class_buttonright'] = $str_value;
    // Class Buttonright


    ///////////////////////////////////////////
    //
    // Input Size

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['input_size'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.input_size is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.input_size '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    if (!$str_value)       // <- Downwards Compatibilty (upto 1.0)
    {                      // <- Downwards Compatibilty (upto 1.0)
      $str_value = $this->pObj->row['form_size_input'];
      if (!$str_value)
      {
         if ($this->pObj->b_drs_plugin)
        {
          GeneralUtility::devlog('[INFO/PLUGIN] The size property of the input field hasn\'t any value. It\'s OK.', $this->pObj->extKey, 0);
        }
      }
    }                      // <- Downwards Compatibilty (upto 1.0)
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Size input field: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['input_size'] = $str_value;
    // Input Size


    ///////////////////////////////////////////
    //
    // Tabindex Input

    // Downwards Compatibilty (upto 1.0)
    $str_value = $this->conf['form.']['tabindex.']['input'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.tabindex.input is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.tabindex.input '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    $str_value = $this->conf['form.']['tabindex.']['input'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.tabindex.subscribe is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.tabindex.subscribe '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    $str_value = $this->conf['form.']['tabindex.']['subscribe'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.tabindex.unsubscribe is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.tabindex.unsubscribe '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    $str_value = $this->conf['form.']['tabindex.']['unsubscribe'];
    if ($str_value)
    {
      if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[WARN/UPDATE] form.tabindex.input is set. The TypoScript property is depricated.', $this->pObj->extKey, 2);
        GeneralUtility::devlog('[HELP/UPDATE] Please remove it!', $this->pObj->extKey, 1);
      }
      $int_key        = count($this->pObj->arrPluginStatus['WARN']);
      $str_depricated = $this->pObj->pi_getLL('plugin_prompt_isDepricated', '', TRUE);
      $this->pObj->arrPluginStatus['WARN'][$int_key]['prompt'] = 'TypoScript form.tabindex.input '.$str_depricated;
      $this->pObj->arrPluginStatus['WARN'][$int_key]['todo']   = $this->pObj->pi_getLL('pluging_todo_rm', '', TRUE);
    }
    // Downwards Compatibilty (upto 1.0)

    $str_value = $this->pObj->row['form_tabindex'];
    if (!$str_value)
    {
       if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[INFO/PLUGIN] The tabindex hasn\'t any value. It\'s OK.', $this->pObj->extKey, 0);
      }
    }
    if ($this->pObj->b_drs_plugin)
    {
      GeneralUtility::devlog('[INFO/PLUGIN] Tabindex: '.htmlspecialchars($str_value), $this->pObj->extKey, 0);
    }
    $arrConfig['tabindex'] = $str_value;
    // Tabindex


    ///////////////////////////////////////////
    //
    // Return the array arrConfig

    return $arrConfig;
    // Return the array arrConfig
  }









  /***********************************************
   *
   * Get Datas from the SQL Record
   *
   **********************************************/




/**
 * Allocates values from the SQL record to
 * - row
 *
 * @return	boolean
 */
  function get_confRecord()
  {

    //////////////////////////////////////////////////////////////////////
    //
    // Get Record

    $select_fields   = '*';
    $from_table      = 'tx_majordomo_conf';
    $where_clause    = 'uid = '.$this->uid;

    // For Development
    if (1==0)
    {
      $query     = $GLOBALS['TYPO3_DB']->SELECTquery($select_fields,$from_table,$where_clause,$groupBy='',$orderBy='',$limit='');
      GeneralUtility::devlog('[INFO/SQL] '.$query, $this->pObj->extKey, 0);
    }
    // For Development

    $rows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows($select_fields,$from_table,$where_clause,$groupBy='',$orderBy='',$limit='',$uidIndexField='');
    if (!is_array($rows))
    {
       if ($this->pObj->b_drs_plugin)
      {
        GeneralUtility::devlog('[ERROR/PLUGIN] The Plugin isn\'t linked with any configuration record.', $this->pObj->extKey, 3);
        GeneralUtility::devlog('[HELP/PLUGIN] Configure the Plugin.', $this->pObj->extKey, 2);
      }
      return FALSE;
    }
    $this->pObj->row = $rows[0];
    // Get Record

      return true;

  }
}