<?php
namespace Netzmacher\Majordomo;

use TYPO3\CMS\Core\Utility\GeneralUtility;

/***************************************************************
*  Copyright notice
*
*  (c) 2007-2017 - Dirk Wildt <wildt.at.die-netzmacher.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * The class tx_majordomo_pi1_content bundles output and HTML methods.
 *
 * @author    Dirk Wildt <wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_majordomo_pi1
 */
class tx_majordomo_pi1_content
{

    /**
     * @var \Netzmacher\Majordomo\tx_majordomo_pi1
     */
    public $pObj = null;
    // Parent Object - Initiated by the constructor

    // Vars set by methods in the current class
    /**
     * @var array
     */
    public $conf = [];












/**
 * Returns the content depending of the content type
 *
 * @return  string    $content: HTML code
 */
  function main()
  {

    //////////////////////////////////////////////////////////////////////
    //
    // Content is depending on case of content type

    switch($this->pObj->plugin_contentType)
    {
      case('confirm'):
        $content = $this->confirm();
        break;
      case('form'):
        $content = $this->form();
        break;
      default:
        if ($this->pObj->b_drs_error)
        {
          GeneralUtility::devlog('[ERROR/PLUGIN] Content Type is undefined. Value: '.$this->pObj->plugin_contentType, $this->pObj->extKey, 3);
        }
        $content = '
          <div style="color:red;font-weight:bold;padding:1em;border:.4em solid red;">
            <h1>
              '.$this->pObj->pi_getLL('plugin_error_title', '', TRUE).'
            </h1>
            <p>
              '.$this->pObj->pi_getLL('plugin_error_prompt', '', TRUE).'
            </p>
          </div>';
        return $content;
    }
    // Content is depending on case of content type

    return $content;
  }










  /**
 * The method generates the html form for subscribing and unsubscribing
 *
 * @return  string    Html form for subscribing and unsubscribing
 */
  function form()
  {

    ///////////////////////////////////////////
    //
    // We like short names

    $prefixId   = $this->pObj->prefixId;
    $arrConfig  = $this->pObj->arrConfig;
    // We like short names


    ///////////////////////////////////////////
    //
    // Set the default email

    $str_defMail   = $arrConfig['default_mail'];
    $arrPost       = GeneralUtility::_POST($prefixId);
    // Security Fix: TYPO3-announce Ticket#2010011310000016
    $str_mail      = htmlentities($arrPost['eMail']);
    // Security Fix: TYPO3-announce Ticket#2010011310000016
    switch(TRUE) {
      case($str_mail <> ''):
        $strMail = $str_mail;
        break;
      default:
    ###    $strMail = $str_defMail; #@ToDo: clean switch statement
        break;
    }
    // Set the default email


    ///////////////////////////////////////////
    //
    // Wrap the header

    $arr_titleWrap  = explode('|', $arrConfig['wrap_header']);
    $str_header     = $arr_titleWrap[0].$this->pObj->pi_getLL('form_title', '', FALSE).$arr_titleWrap[1];
    // Wrap the header

    ///////////////////////////////////////////
    //
    // Get Tab Indexes

    $arr_tabIndex = explode('|', $arrConfig['tabindex']);
    $str_tabindex_0 = FALSE;
    $str_tabindex_1 = FALSE;
    $str_tabindex_2 = FALSE;
    if($arr_tabIndex[0] != '')
    {
      $str_tabindex_0 = ' tabindex="'.$arr_tabIndex[0].'"';
    }
    if($arr_tabIndex[1] != '')
    {
      $str_tabindex_1 = ' tabindex="'.$arr_tabIndex[1].'"';
    }
        if($arr_tabIndex[2] != '')
    {
      $str_tabindex_2 = ' tabindex="'.$arr_tabIndex[2].'"';
    }
    // Get Tab Indexes


    ///////////////////////////////////////////
    //
    // Building the content

    $content = '
        '.$str_header.'
        <form class="'.$prefixId.'" action="'.$arrConfig['form_action'].'" method="post">
          <div class="'.$arrConfig['class_buttons'].'">
            <input type="hidden" name="no_cache" value="1">
            <input type="email" class="email form-control" name="'.$prefixId.'[eMail]" size="'.$arrConfig['input_size'].'" maxlength="255"
              placeholder="'.$str_defMail.'" value="'.$strMail.'"'.$str_tabindex_0.' required="required">
            <div class="'.$arrConfig['class_buttonleft'].'">
              <input type="submit" class="subscribe btn btn-success" name="'.$prefixId.'[subscribe]" value="'.$this->pObj->pi_getLL('html_subscribe_button_value', '', FALSE).'"
                title="'.$this->pObj->pi_getLL('html_subscribe_button_title', '', FALSE).'"'.$str_tabindex_1.'>
            </div>
            <div class="'.$arrConfig['class_buttonright'].'">
              <input type="submit" class="unsubscribe unsubscribe btn btn-warning" name="'.$prefixId.'[unsubscribe]" value="'.$this->pObj->pi_getLL('html_unsubscribe_button_value', '', FALSE).'"
                title="'.$this->pObj->pi_getLL('html_unsubscribe_button_title', '', FALSE).'"'.$str_tabindex_2.'>
            </div>
          </div>
        </form>
';
    // Building the content


    ///////////////////////////////////////////
    //
    // Return the content

    return $content;
    // Return the content
  }
















  /**
 * The method sends one mail to majordomo and another to the subscriber/unsubscriber.
 *
 * @return  string    Message in html for displaying on the website
 */
  function confirm()
  {
    ///////////////////////////////////////////
    //
    // We like short names
    
    $prefixId   = $this->pObj->prefixId;
    $arrConfig  = $this->pObj->arrConfig;
    // We like short names


    ///////////////////////////////////////////
    //
    // Set the language key
    
    $langKey = $GLOBALS['TSFE']->lang;
    if($langKey == 'en')
    {
      $langKey = 'default';
    }
    // Set the language key


    ///////////////////////////////////////////
    //
    // Wraps

    $arr_titleWrap      = explode('|', $arrConfig['wrap_header']);
    $arr_promptWrap     = explode('|', $arrConfig['wrap_prompt']);
    $arr_wrongMailWrap  = explode('|', $arrConfig['wrap_wrongmail']);
    // Wraps

    ///////////////////////////////////////////
    //
    // Values

    $str_mdom_mail    = $arrConfig['mdom_mail'];
    $str_mdom_list    = $arrConfig['mdom_list'];
    $str_mdom_owner   = $arrConfig['mdom_owner'];
    $str_sender_from  = $arrConfig['sender_from'];
    $str_sender_name  = $arrConfig['sender_name'];
    $str_signature    = $arrConfig['sender_signature'];
    // Values

    ///////////////////////////////////////////
    //
    // Charset

    $int_charset      = $arrConfig['sender_charset'];
    switch($int_charset)
    {
      case(1):
        $str_charset = 'iso-8859-15';
        break;
      default:
        $str_charset = 'utf-8';
    }
    // Charset


    ///////////////////////////////////////////
    //
    // Do we have a proper email?

    $content = $this->pObj->objZz->eval_email();
    if($content)
    {
      // No. RETURN the message of the eval method
      return $content;
    }
    // Do we have a proper email?


    ///////////////////////////////////////////
    //
    // POST_VARS
    $arrPost = GeneralUtility::_POST($prefixId);
    // Security Fix: TYPO3-announce Ticket#2010011310000016
    $str_mail      = htmlentities($arrPost['eMail']);
    // Security Fix: TYPO3-announce Ticket#2010011310000016
    // POST_VARS


    ///////////////////////////////////////////
    //
    // Case is SUBSCRIBE

    if ($arrPost['subscribe'] <> '')
    {
      // For the Email to the Majordomo Server
      $strSubject_01 = $this->pObj->pi_getLL('majordomo_subscribe_subject', '', FALSE);
      $strSubject_01 = str_replace('###LIST###', $str_mdom_list, $strSubject_01);
//      if ($str_charset != 'utf-8')
//      {
//        $strSubject_01 = utf8_decode($strSubject_01);
//      }
      $strMessage_01 = $this->pObj->pi_getLL('majordomo_subscribe_body', '', FALSE);
      $strMessage_01 = str_replace('###MAIL###', $str_mail, $strMessage_01);
      $strMessage_01 = str_replace('###LIST###', $str_mdom_list, $strMessage_01);
//      if ($str_charset != 'utf-8')
//      {
//        $strMessage_01 = utf8_decode($strMessage_01);
//      }
      // For the Email to the Majordomo Server

      // For the Email to the Subscriber
      $strSubject_02 = $this->pObj->pi_getLL('mail_subscribe_subject', '', FALSE);
      $strSubject_02 = str_replace('###LIST###', $str_mdom_list, $strSubject_02);
      if ($str_charset != 'utf-8')
      {
        $strSubject_02 = utf8_decode($strSubject_02);
      }
      $strMessage_02 = $this->pObj->pi_getLL('mail_subscribe_body', '', FALSE);
      $strMessage_02 = str_replace('###MAIL###',      $str_mail,  $strMessage_02);
      $strMessage_02 = str_replace('###LIST###',      $str_mdom_list,     $strMessage_02);
      $strMessage_02 = str_replace('###OWNER###',     $str_mdom_owner,    $strMessage_02);
      $strMessage_02 = str_replace('###NAME###',      $str_sender_name,   $strMessage_02);
      $strMessage_02 = str_replace('###SIGNATURE###', $str_signature,     $strMessage_02);
      $strMessage_02 = str_replace('###BR###',        "\r\n",             $strMessage_02);
      if ($str_charset != 'utf-8')
      {
        $strMessage_02 = utf8_decode($strMessage_02);
      }
      $content = ''.
'        '.$arr_titleWrap[0].'
        '.$this->pObj->pi_getLL('html_subscribe_title', '', FALSE).'
        '.$arr_titleWrap[1].'
        '.$arr_promptWrap[0].'
        '.$this->pObj->pi_getLL('html_subscribe_text', '', FALSE).'
        '.$arr_promptWrap[1].'
';
      // For the Email to the Subscriber
    }
    // Case is SUBSCRIBE


    ///////////////////////////////////////////
    //
    // Case is UNSUBSCRIBE

    if ($arrPost['unsubscribe'] <> '')
    {
      // For the Email to the Majordomo Server
      $strSubject_01 = $this->pObj->pi_getLL('majordomo_unsubscribe_subject', '', FALSE);
      $strSubject_01 = str_replace('###LIST###', $str_mdom_list, $strSubject_01);
      //$strSubject_01 = utf8_decode($strSubject_01);
      $strMessage_01 = $this->pObj->pi_getLL('majordomo_unsubscribe_body', '', FALSE);
      $strMessage_01 = str_replace('###MAIL###', $str_mail, $strMessage_01);
      $strMessage_01 = str_replace('###LIST###', $str_mdom_list, $strMessage_01);
      //$strMessage_01 = utf8_decode($strMessage_01);
      // For the Email to the Majordomo Server

      // For the Email to the Subscriber
      $strSubject_02 = $this->pObj->pi_getLL('mail_unsubscribe_subject', '', FALSE);
      $strSubject_02 = str_replace('###LIST###', $str_mdom_list, $strSubject_02);
      if ($str_charset != 'utf-8')
      {
        $strMessage_01 = utf8_decode($strMessage_01);
      }
      $strMessage_02 = $this->pObj->pi_getLL('mail_unsubscribe_body', '', FALSE);
      $strMessage_02 = str_replace('###MAIL###',      $str_mail,  $strMessage_02);
      $strMessage_02 = str_replace('###LIST###',      $str_mdom_list,     $strMessage_02);
      $strMessage_02 = str_replace('###OWNER###',     $str_mdom_owner,    $strMessage_02);
      $strMessage_02 = str_replace('###NAME###',      $str_sender_name,   $strMessage_02);
      $strMessage_02 = str_replace('###SIGNATURE###', $str_signature,     $strMessage_02);
      $strMessage_02 = str_replace('###BR###',        "\r\n",             $strMessage_02);
      if ($str_charset != 'utf-8')
      {
        $strMessage_02 = utf8_decode($strMessage_02);
      }
      $content = ''.
'        '.$arr_titleWrap[0].'
        '.$this->pObj->pi_getLL('html_unsubscribe_title', '', FALSE).'
        '.$arr_titleWrap[1].'
        '.$arr_promptWrap[0].'
        '.$this->pObj->pi_getLL('html_unsubscribe_text', '', FALSE).'
        '.$arr_promptWrap[1].'
';
      // For the Email to the Subscriber
    }
    // Case is UNSUBSCRIBE


    ///////////////////////////////////////////
    //
    // Send Emails

    // Send email to the address of the Majordomo Server
    if ($this->pObj->b_drs_email)
    {
      $str_prompt = 'To: '.$str_mdom_mail.'<br />';
      $str_prompt = $str_prompt.'From: '.$str_mail.'<br />';
      $str_prompt = $str_prompt.'Subject:'.htmlspecialchars($strSubject_01).'<br />';
      $str_prompt = $str_prompt.htmlspecialchars($strMessage_01);
      GeneralUtility::devlog('[INFO/EMAIL] Email to Majordomo Server:<br /><br />'.$str_prompt, $this->pObj->extKey, 0);
      $prompt = 'Change the email template? Please configure<br />
         _LOCAL_LANG.'.$langKey.'.majordomo_subscribe_subject<br />
         _LOCAL_LANG.'.$langKey.'.majordomo_subscribe_body<br />
         _LOCAL_LANG.'.$langKey.'.majordomo_unsubscribe_subject<br />
         _LOCAL_LANG.'.$langKey.'.majordomo_unsubscribe_body<br />
         <br />
         See file: Resources/Private/Language/locallang.xlf';
      GeneralUtility::devlog('[HELP/LOCALLANG] '.$prompt, $this->pObj->extKey, 1);
    }
    if ($this->pObj->b_drs_checkmode)
    {
      GeneralUtility::devlog('[WARN/CHECK_MODE] Check mode is running: Mail isn\'t sent.', $this->pObj->extKey, 2);
    }
    if (!$this->pObj->b_drs_checkmode)
    {
       mail($str_mdom_mail, $strSubject_01, $strMessage_01, "From: ".$str_mail."\r\n");
    }
    // Send email to the address of the Majordomo Server

    // Send email to subscriber or unsubscriber respectively
    $strHeader  = "MIME-Version: 1.0\r\n";
    $strHeader .= "Content-type: text/plain; charset=".$str_charset."\r\n";
    $strHeader .= "FROM: ".$str_sender_from."\r\n";
    $strHeader .= "REPLY-TO: ".$str_mdom_owner."\r\n";
    if ($this->pObj->b_drs_email)
    {
      $str_prompt = 'To: '.$str_mail.'<br />';
      $str_prompt = $str_prompt.nl2br($strHeader).'<br />';
      $str_prompt = $str_prompt.'Subject:'.htmlspecialchars($strSubject_02).'<br />';
      $str_prompt = $str_prompt.nl2br(htmlspecialchars($strMessage_02));
      GeneralUtility::devlog('[INFO/EMAIL] Email to Majordomo Server:<br /><br />'.$str_prompt, $this->pObj->extKey, 0);
      $prompt = 'Change the email template? Please configure<br />
         _LOCAL_LANG.'.$langKey.'.mail_subscribe_subject<br />
         _LOCAL_LANG.'.$langKey.'.mail_subscribe_body<br />
         _LOCAL_LANG.'.$langKey.'.mail_unsubscribe_subject<br />
         _LOCAL_LANG.'.$langKey.'.mail_unsubscribe_body<br />
         <br />
         See file: Resources/Private/Language/locallang.xlf';
      GeneralUtility::devlog('[HELP/LOCALLANG] '.$prompt, $this->pObj->extKey, 1);
    }
    if ($this->pObj->b_drs_checkmode)
    {
      GeneralUtility::devlog('[WARN/CHECK_MODE] Check mode is running: Mail isn\'t sent.', $this->pObj->extKey, 2);
    }
    if (!$this->pObj->b_drs_checkmode)
    {
      mail($str_mail, $strSubject_02, $strMessage_02, $strHeader);
    }
    // Send email to subscriber or unsubscriber respectively
    // Send Emails


    ///////////////////////////////////////////
    //
    // RETURN the content

    $content = str_replace('###MAIL###', $str_mail, $content);
    return $content;
    // RETURN the content
  }
}